AudioCtrl

Struct AudioCtrl 

pub struct AudioCtrl(/* private fields */);
Audio master control (NR52).

BitFieldAccessMeaning
7audio_onR/WMaster audio power; off clears and locks the other registers.
6-4Unused.
3ch4_onROChannel 4 (noise) is running.
2ch3_onROChannel 3 (wave) is running.
1ch2_onROChannel 2 (pulse) is running.
0ch1_onROChannel 1 (pulse) is running.

Implementations

Source

impl AudioCtrl

pub const fn new() -> Self

Creates a new default initialized bitfield.

pub const fn from_bits(bits: u8) -> Self

Convert from bits.

pub const fn into_bits(self) -> u8

Convert into bits.

pub const fn ch1_on(&self) -> bool

Channel 1 (pulse) is running (read-only status).

Bits: 0..1

pub const fn ch2_on(&self) -> bool

Channel 2 (pulse) is running (read-only status).

Bits: 1..2

pub const fn ch3_on(&self) -> bool

Channel 3 (wave) is running (read-only status).

Bits: 2..3

pub const fn ch4_on(&self) -> bool

Channel 4 (noise) is running (read-only status).

Bits: 3..4

pub const fn audio_on(&self) -> bool

Master audio power. Turning it off clears and locks the other registers.

Bits: 7..8

pub const fn with_audio_on_checked(self, value: bool) -> Result<Self, ()>

Master audio power. Turning it off clears and locks the other registers.

Bits: 7..8

pub const fn with_audio_on(self, value: bool) -> Self

Master audio power. Turning it off clears and locks the other registers.

Bits: 7..8

pub const fn set_audio_on(&mut self, value: bool)

Master audio power. Turning it off clears and locks the other registers.

Bits: 7..8

pub const fn set_audio_on_checked(&mut self, value: bool) -> Result<(), ()>

Master audio power. Turning it off clears and locks the other registers.

Bits: 7..8